@@ -121,6 +121,40 @@ def prediction_chart(prediction_list):
     return chart
 
 
+def class_accuracy(matrix):
+    confusion_matrix = matrix.copy()
+    for i in range(10):
+        ratio = np.sum(confusion_matrix[i])
+        confusion_matrix[i] *= 100 / ratio
+
+    confusion_matrix = np.around(confusion_matrix)
+
+    x = [confusion_matrix[i, i] for i in range(10)]
+
+    df = pd.DataFrame(
+        {
+            "acc": x,
+            "class": list(range(10)),
+        }
+    )
+
+    bars = (
+        alt.Chart(df)
+        .mark_bar()
+        .encode(
+            alt.X("acc:Q", axis=alt.Axis(title="Accuracy")),
+            alt.Y("class:O", axis=alt.Axis(title="Classes")),
+        )
+    )
+    text = bars.mark_text(
+        align="left",
+        baseline="middle",
+        dx=3,  # Nudges text to right so it doesn't appear on top of the bar
+    ).encode(text="acc:Q")
+
+    return (bars + text).properties(width="container", height=500)
+
+
 def confusion_matrix_chart(matrix):
     x, y = np.meshgrid(range(0, 10), range(0, 10))
     df = pd.DataFrame(
@@ -139,9 +173,10 @@ def confusion_matrix_chart(matrix):
             y=alt.Y("y:O", axis=alt.Axis(title="Classification")),
             color=alt.Color(
                 "z:Q",
+                title="",
                 scale=alt.Scale(
                     scheme="inferno",
-                    domain=[-15, 115],
+                    domain=[-15, np.amax(matrix)],
                 ),
             ),
             # tooltip=[
@@ -159,4 +194,4 @@ def confusion_matrix_chart(matrix):
         color=alt.condition(alt.datum.z < 20, alt.value("white"), alt.value("black")),
     )
 
-    return (chart + text).properties(width="container", height="container")
+    return (chart + text).properties(width="container", height=500)
