@@ -1,7 +1,6 @@
 import random
 import numpy as np
 import torchvision
-from pathlib import Path
 
 from .common import DATA_DIR, get_model, has_trained_model
 
@@ -42,4 +41,4 @@ def prediction_update():
 
 
 def prediction_xai_params():
-    return MODEL.model, np.asarray(LAST_IMAGE)
+    return MODEL, np.asarray(LAST_IMAGE)
