@@ -1,8 +1,6 @@
 import torch
 import torchvision
-import torch.nn as nn
 import numpy as np
-import time
 
 from .common import DATA_DIR, TRANSFORM
 from .prediction import get_model
@@ -31,18 +29,15 @@ def winner_class(classes):
 
 @torch.no_grad()
 def testing_run(datasets=LOADER_TEST):
-    model = get_model().model
+    device, model = get_model().device, get_model().model
     model.eval()
     confusion_matrix = np.zeros((10, 10), dtype=np.float64)
     for inputs, targets in datasets:
-        outputs = model(inputs).numpy()
+        inputs, targets = inputs.to(device), targets.to(device)
+        outputs = model(inputs).cpu().numpy()
         for i in range(inputs.shape[0]):
             confusion_matrix[winner_class(outputs[i])][int(targets[i])] += 1
 
-    # Normalize
     total = np.sum(confusion_matrix)
-    for i in range(10):
-        ratio = np.sum(confusion_matrix[i])
-        confusion_matrix[i] *= 100 / ratio
 
     return np.around(confusion_matrix), int(total)
